yakumo.cinder.v2.snapshot.Manager

Package yakumo :: Package cinder :: Package v2 :: Module snapshot :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for volume snapshots on Block Storage V2 API

Nested Classes | [hide private]
| resource_class resource class for volume snapshots on Block Storage V2 API

Instance Methods | [hide private]
yakumo.cinder.v2.snapshot.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`, source=`'``__UNDEF__``'`, force=False) Create a snapshot of a volume | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``volume``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``snapshot``'``
| _json_resources_key = ``'``snapshots``'``
| _hidden_methods = ``[``'``update``'``]``
| _url_resource_list_path = ``'``/snapshots/detail``'``
| _url_resource_path = ``'``/snapshots``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`, source=`'``__UNDEF__``'`, force=False) | source code
Create a snapshot of a volume Parameters: `name` (str) - Snapshot name `description` (str) - Description `metadata` (dict) - Metadata `source` (yakumo.cinder.v2.volume.Resource) - Source volume Returns: yakumo.cinder.v2.snapshot.Resource Created volume object Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('name', 'name', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('description',
        'description',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('size', 'size', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('status',
        'status',
      ...